<?php

namespace drp\AdminPanel\User;

use Illuminate\Support\ServiceProvider;

class UserServiceProvider extends ServiceProvider
{
    /**
     * Perform post-registration booting of services.
     *
     * @return void
     */
    public function boot()
    {
        $this->loadViewsFrom(realpath(__DIR__.'/Views'), 'DrpUserAdmin');

        $this->publishes([
            __DIR__.'/Migrations' => database_path('migrations')
        ], 'migrations');

        $this->publishes([
            __DIR__.'/Seeders' => database_path('seeds')
        ], 'seeds');

        if (config('drpadmin.useAdminRoutes') &&
            !$this->app->routesAreCached() ||
            config('drpadmin') == false
        ) {
            $baseRoutePath = config('drpadmin.baseRoutePath');
            require __DIR__ . '/Http/routes.php';
        }

        $router = $this->app->make('router');
        $router->middleware('admin-role', 'drp\AdminPanel\User\Middleware\RoleMiddleware');

        $sidebar = $this->app->make('Sidebar');
        $sidebar->addMultiLevelItem('fa-users', 'Users', true)
                    ->addItem('fa-list', 'All', route('admin.users.index', [], false))
                    ->addItem('fa-pencil', 'Create', route('admin.users.create', [], false));
    }

    /**
     * Register any package services.
     *
     * @return void
     */
    public function register()
    {
    }
}
